==> humhub-1.4.1.tar.gz: humhub-1.4.1/protected/humhub/modules/user/messages/de/auth.php <==
<?php
return array (
  '<strong>Account</strong> registration' => '<strong>Konto</strong>-Registrierung',
  '<strong>Change</strong> your password' => '<strong>Ändere</strong> dein Passwort',
  '<strong>Join</strong> the network' => 'Netzwerk <strong>beitreten</strong>',
  '<strong>Password</strong> changed!' => '<strong>Passwort</strong> geändert!',
  '<strong>Password</strong> recovery' => '<strong>Passwort</strong>-Wiederherstellung!',
  '<strong>Password</strong> recovery!' => '<strong>Passwort</strong>-Wiederherstellung!',
  '<strong>Please</strong> sign in' => '<strong>Bitte</strong> einloggen',
  '<strong>Registration</strong> successful!' => '<strong>Registrierung</strong> erfolgreich!',
  '<strong>Sign</strong> up' => '<strong>Registrieren</strong>',
  '<strong>Your account</strong> has been successfully created!' => '<strong>Dein Konto</strong> wurde erfolgreich erstellt!',
  'Account' => 'Konto',
  'After activating your account by the administrator, you will receive a notification by email.' => 'Nach der Aktivierung deines Kontos durch einen Administrator erhältst du  eine Benachrichtigung per E-Mail.',
  'Back' => 'Zurück',
  'Change password' => 'Passwort ändern',
  'Create Account' => 'Konto anlegen',
  'Create account' => 'Konto erstellen',
  'Don\'t have an account? Join the network by entering your e-mail address.' => 'Noch kein Benutzerkonto? Werde Mitglied, indem du deine E-Mail Adresse eingibst.',
  'Enter security code above' => 'Bitte gib den Sicherheitscode ein',
  'Forgot your password?' => 'Passwort vergessen?',
  'Go to login page' => 'Zur Loginseite',
  'Group' => 'Gruppe',
  'Hello {displayName}' => 'Hallo {displayName}',
  'Hello {displayName},' => 'Hallo {displayName},',
  'If you don\'t use this link within 24 hours, it will expire.' => 'Wenn du diesen Link nicht innerhalb der nächsten 24 Stunden nutzt wird er ungültig.',
  'If you\'re already a member, please login with your username/email and password.' => 'Wenn du bereits Mitglied bist, logge dich bitte mit Benutzername/E-Mail und Passwort ein.',
  'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Gib einfach deine E-Mail Adresse ein, und wir senden dir eine Mail um dein Passwort neu zu setzen.',
  'Login' => 'Login',
  'New user needs approval' => 'Neuer Benutzer benötigt Freischaltung',
  'Password recovery' => 'Passwort-Wiederherstellung',
  'Password reset' => 'Passwort zurücksetzen',
  'Please check your email and follow the instructions!' => 'Bitte prüfe dein E-Mail-Postfach und folge den Anweisungen!',
  'Please click on the link below to view request:' => 'Um die Anfrage anzusehen, klicke auf den folgenden Link:',
  'Please enter the letters from the image.' => 'Bitte geben Sie die Buchstaben aus dem Bild ein.',
  'Please login with your username/email and password.' => 'Bitte melde dich mit Deinem Benutzernamen/Email und Deinem Passwort an.',
  'Please use the following link within the next day to reset your password.' => 'Nutze den folgenden Link innerhalb des nächsten Tages um dein Passwort neu zu setzen.',
  'Register' => 'Registrieren',
  'Registration successful' => 'Registrierung erfolgreich',
  'Remember me' => 'Angemeldet bleiben',
  'Reset Password' => 'Passwort zurücksetzen',
  'Reset password' => 'Passwort zurücksetzen',
  'Sign in' => 'Einloggen',
  'To log in with your new account, click the button below.' => 'Um dich mit deinem neuen Konto einzuloggen, klicke unten auf den Button.',
  'We’ve sent you an email containing a link that will allow you to reset your password.' => 'Wir haben Dir eine E-Mail mit einem Link geschickt, mit dem du Dein Passwort zurücksetzen kannst.',
  'Your email' => 'Deine E-Mail',
  'Your password' => 'Dein Passwort',
  'Your password has been successfully changed!' => 'Dein Passwort wurde erfolgreich geändert!',
  'Your password is incorrect!' => 'Dein Passwort ist nicht korrekt!',
  'a new user {displayName} needs approval.' => 'Neuer Benutzer {displayName} benötigt eine Freischaltung.',
  'back to home' => 'zurück zur Startseite',
  'email' => 'E-Mail',
  'password' => 'Passwort',
  'username or email' => 'Benutzername oder E-Mail',
);

==> humhub-1.4.2.tar.gz: humhub-1.4.2/protected/humhub/modules/user/messages/de/auth.php <==
<?php
return array (
  '<strong>Account</strong> registration' => '<strong>Benutzerkonto</strong>-Registrierung',
  '<strong>Change</strong> your password' => '<strong>Ändere</strong> dein Passwort',
  '<strong>Join</strong> the network' => '%appName% <strong>beitreten</strong>',
  '<strong>Password</strong> changed!' => '<strong>Passwort</strong> geändert!',
  '<strong>Password</strong> recovery' => '<strong>Passwort</strong>-Wiederherstellung!',
  '<strong>Password</strong> recovery!' => '<strong>Passwort</strong>-Wiederherstellung!',
  '<strong>Please</strong> sign in' => '<strong>Bitte</strong> einloggen',
  '<strong>Registration</strong> successful!' => '<strong>Registrierung</strong> erfolgreich!',
  '<strong>Sign</strong> up' => '<strong>Registrieren</strong>',
  '<strong>Your account</strong> has been successfully created!' => '<strong>Dein Benutzerkonto</strong> wurde erfolgreich erstellt!',
  'Account' => 'Benutzerkonto',
  'After activating your account by the administrator, you will receive a notification by email.' => 'Nach der Aktivierung deines Kontos durch einen Administrator erhältst du  eine Benachrichtigung per E-Mail.',
  'Back' => 'Zurück',
  'Change password' => 'Passwort ändern',
  'Create Account' => 'Benutzerkonto anlegen',
  'Create account' => 'Benutzerkonto erstellen',
  'Don\'t have an account? Join the network by entering your e-mail address.' => 'Noch kein Benutzerkonto? Werde Mitglied, indem du deine E-Mail Adresse eingibst.',
  'Enter security code above' => 'Bitte gib den Sicherheitscode ein',
  'Forgot your password?' => 'Passwort vergessen?',
  'Go to login page' => 'Zur Loginseite',
  'Group' => 'Gruppe',
  'Hello {displayName}' => 'Hallo {displayName}',
  'Hello {displayName},' => 'Hallo {displayName},',
  'If you don\'t use this link within 24 hours, it will expire.' => 'Wenn du diesen Link nicht innerhalb der nächsten 24 Stunden nutzt, wird er ungültig.',
  'If you\'re already a member, please login with your username/email and password.' => 'Wenn du bereits Mitglied bist, logge dich bitte mit Benutzername/E-Mail und Passwort ein.',
  'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Gib einfach deine E-Mail Adresse ein und wir senden dir eine Mail um dein Passwort neu zu setzen.',
  'Login' => 'Login',
  'New user needs approval' => 'Neuer Benutzer benötigt Freischaltung',
  'Password recovery' => 'Passwort-Wiederherstellung',
  'Password reset' => 'Passwort zurücksetzen',
  'Please check your email and follow the instructions!' => 'Bitte prüfe dein E-Mail-Postfach und folge den Anweisungen!',
  'Please click on the link below to view request:' => 'Um die Anfrage anzusehen, klicke auf den folgenden Link:',
  'Please enter the letters from the image.' => 'Bitte gib die Buchstaben aus dem Bild ein.',
  'Please login with your username/email and password.' => 'Bitte melde dich mit deinem Benutzernamen/E-Mail und deinem Passwort an.',
  'Please use the following link within the next day to reset your password.' => 'Nutze den folgenden Link innerhalb des nächsten Tages um dein Passwort neu zu setzen.',
  'Register' => 'Registrieren',
  'Registration successful' => 'Registrierung erfolgreich',
  'Remember me' => 'Angemeldet bleiben',
  'Reset Password' => 'Passwort zurücksetzen',
  'Reset password' => 'Passwort zurücksetzen',
  'Sign in' => 'Einloggen',
  'To log in with your new account, click the button below.' => 'Um dich mit deinem neuen Benutzerkonto einzuloggen, klicke unten auf den Button.',
  'We’ve sent you an email containing a link that will allow you to reset your password.' => 'Wir haben dir eine E-Mail mit einem Link geschickt, mit dem du dein Passwort zurücksetzen kannst.',
  'Your email' => 'Deine E-Mail',
  'Your password' => 'Dein Passwort',
  'Your password has been successfully changed!' => 'Dein Passwort wurde erfolgreich geändert!',
  'Your password is incorrect!' => 'Dein Passwort ist nicht korrekt!',
  'a new user {displayName} needs approval.' => 'Neuer Benutzer {displayName} benötigt eine Freischaltung.',
  'back to home' => 'zurück zur Startseite',
  'email' => 'E-Mail',
  'password' => 'Passwort',
  'username or email' => 'Benutzername oder E-Mail',
);
